==> qiskit_aqua-0.5.0-py3-none-any.whl: qiskit/aqua/components/neural_networks/discriminative_network.py <==
# -*- coding: utf-8 -*-

# This code is part of Qiskit.
#
# (C) Copyright IBM 2019.
#
# This code is licensed under the Apache License, Version 2.0. You may
# obtain a copy of this license in the LICENSE.txt file in the root directory
# of this source tree or at http://www.apache.org/licenses/LICENSE-2.0.
#
# Any modifications or derivative works of this code must retain this
# copyright notice, and modified files need to carry a notice indicating
# that they have been altered from the originals.

from abc import abstractmethod

from qiskit.aqua import Pluggable


class DiscriminativeNetwork(Pluggable):
    """Base class for discriminative Quantum or Classical Neural Networks.

        This method should initialize the module and its configuration, and
        use an exception if a component of the module is
        available.
    """
    @abstractmethod
    def __init__(self):
        super().__init__()
        self._num_parameters = 0
        self._num_qubits = 0
        self._bounds = list()
        pass

    @classmethod
    def init_params(cls, params):
        discriminative_params = params.get(Pluggable.SECTION_KEY_DISCRIMINATIVE_NETWORK)
        args = {k: v for k, v in discriminative_params.items() if k != 'name'}

        return cls(**args)

    @classmethod
    @abstractmethod
    def get_section_key_name(cls):
        pass

    @abstractmethod
    def set_seed(self, seed):
        """
        Set seed.
        Args:
            seed: int, seed

        Returns:

        """
        raise NotImplementedError()

    @abstractmethod
    def get_label(self, x):
        """ Apply quantum/classical neural network to the given input sample and compute the respective data label
        Args:
            x: Discriminator input, i.e. data sample.

        Returns: Computed data label

        """
        raise NotImplementedError()

    @abstractmethod
    def loss(self, x, y, weights=None):
        """Loss function used for optimization

        Args:
            x: Discriminator output.
            y: Label of the data point
            weights: Data weights.

        Returns: Loss w.r.t to the generated data points.

        """
        raise NotImplementedError()

    @abstractmethod
    def train(self, data, weights, penalty=False, quantum_instance=None, shots=None):
        """
        Perform one training step w.r.t to the discriminator's parameters
        Args:
            data: array, Data batch.
            weights: array, Data sample weights.
            penalty: Boolean, Indicate whether or not penalty function is applied to the loss function.
                    If no penalty function defined - depreciate
                        quantum_instance: QuantumInstance, used to run the generator circuit.
                        Depreciated for classical network
            quantum_instance: QuantumInstance
            shots: int, Number of shots for hardware or qasm execution. Depreciated for classical network

        Returns: dict, with Discriminator loss and updated parameters.

        """
        raise NotImplementedError()

==> qiskit_aqua-0.6.5-py3-none-any.whl: qiskit/aqua/components/neural_networks/discriminative_network.py <==
# -*- coding: utf-8 -*-

# This code is part of Qiskit.
#
# (C) Copyright IBM 2019.
#
# This code is licensed under the Apache License, Version 2.0. You may
# obtain a copy of this license in the LICENSE.txt file in the root directory
# of this source tree or at http://www.apache.org/licenses/LICENSE-2.0.
#
# Any modifications or derivative works of this code must retain this
# copyright notice, and modified files need to carry a notice indicating
# that they have been altered from the originals.

""" Discriminative Quantum or Classical Neural Networks. """

from abc import abstractmethod

from qiskit.aqua import Pluggable


class DiscriminativeNetwork(Pluggable):
    """Base class for discriminative Quantum or Classical Neural Networks.

        This method should initialize the module and its configuration, and
        use an exception if a component of the module is
        available.
    """
    @abstractmethod
    def __init__(self):
        super().__init__()
        self._num_parameters = 0
        self._num_qubits = 0
        self._bounds = list()
        pass

    @classmethod
    def init_params(cls, params):
        """ init params """
        discriminative_params = params.get(Pluggable.SECTION_KEY_DISCRIMINATIVE_NET)
        args = {k: v for k, v in discriminative_params.items() if k != 'name'}

        return cls(**args)

    @classmethod
    @abstractmethod
    def get_section_key_name(cls):
        """ get section key names """
        pass

    @abstractmethod
    def set_seed(self, seed):
        """
        Set seed.
        Args:
            seed (int): seed
        Raises:
            NotImplementedError: not implemented
        """
        raise NotImplementedError()

    @abstractmethod
    def get_label(self, x):
        """ Apply quantum/classical neural network to the given input sample and compute
            the respective data label
        Args:
            x (Discriminator): input, i.e. data sample.
        Raises:
            NotImplementedError: not implemented
        """
        raise NotImplementedError()

    @abstractmethod
    def loss(self, x, y, weights=None):
        """Loss function used for optimization

        Args:
            x (Discriminator): output.
            y (Label): the data point
            weights (numpy.ndarray): Data weights.

        Returns:
            Loss w.r.t to the generated data points.
         Raises:
            NotImplementedError: not implemented
        """
        raise NotImplementedError()

    @abstractmethod
    def train(self, data, weights, penalty=False, quantum_instance=None, shots=None):
        """
        Perform one training step w.r.t to the discriminator's parameters
        Args:
            data (numpy.ndarray): Data batch.
            weights (numpy.ndarray): Data sample weights.
            penalty (bool): Indicate whether or not penalty function
                    is applied to the loss function.
                    If no penalty function defined - depreciate
                        quantum_instance: QuantumInstance, used to run the generator circuit.
                        Depreciated for classical network
            quantum_instance (QuantumInstance): Quantum Instance
            shots (int): Number of shots for hardware or qasm execution.
                        Depreciated for classical network
        Returns:
            dict: with Discriminator loss and updated parameters.
        Raises:
            NotImplementedError: not implemented
        """
        raise NotImplementedError()
